@@ -15,11 +15,11 @@ philosophy of The Book of Change(易经);
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 SYNOPSIS
 
@@ -474,7 +474,7 @@ __DATA__
 上九：視履考祥，其旋元吉。
 《象》曰：元吉在上，大有慶也。
  
-《易經》第十一卦泰天地泰坤上乾下
+《易經》第十一卦泰地天泰坤上乾下
  
 泰，小往大來，吉亨。
 《彖》曰：「泰，小往大來，吉亨」，則是天地交而萬物通也，上下交而其志同也。內陽而外陰，內健而外順，內君子而外小人，君子道長，小人道消也。
@@ -492,7 +492,7 @@ __DATA__
 上六：城復于隍，勿用師。自邑告命，貞吝。
 《象》曰：「城復于隍」，其命亂也。
  
-《易經》第十二卦否地天否乾上坤下
+《易經》第十二卦否天地否乾上坤下
  
 否，否之匪人，不利君子貞，大往小來。
 《彖》曰：「否之匪人，不利君子貞，大往小來」，則是天地不交而萬物不通也，上下不交而天下無邦也。內陰而外陽，內柔而外剛，內小人而外君子，小人道長，君子道消也。
